"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _color = _interopRequireDefault(require("color"));

var _Image = _interopRequireDefault(require("./Image"));

var _Card = _interopRequireDefault(require("./Card"));

var _Elevation = _interopRequireDefault(require("./Elevation"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _Config = _interopRequireDefault(require("./Config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const ICON_CONTAINER_SIZE = _Config.default.cardIconSize * 2;
const ICON_CONTAINER_PADDING = _Config.default.cardIconSize / 2 - 1;

const CardContainer = ({
  image = _Config.default.cardImageUrl,
  title,
  leftDescription,
  rightDescription,
  textCentered,
  icon,
  aspectRatio = 1.5,
  elevation = 2,
  numColumns = 3,
  theme: {
    colors,
    borderRadius,
    typography,
    spacing
  },
  style,
  onPress
}) => {
  let textJustification;
  let titleStyle;

  if (textCentered && !rightDescription) {
    textJustification = "center";
  } else {
    textJustification = "space-between";
  }

  switch (numColumns) {
    case 2:
      titleStyle = typography.headline6;
      break;

    case 3:
      titleStyle = typography.headline5;
      break;
  }

  return /*#__PURE__*/_react.default.createElement(_Card.default, {
    style: style,
    onPress: onPress,
    numColumns: numColumns
  }, /*#__PURE__*/_react.default.createElement(_Elevation.default, {
    style: {
      elevation,
      borderRadius: borderRadius.global
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      borderRadius: borderRadius.global,
      overflow: "hidden",
      backgroundColor: colors.surface
    }
  }, /*#__PURE__*/_react.default.createElement(_Image.default, {
    style: {
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      padding: spacing.large
    }
  }, title ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: "row",
      alignItems: "center",
      justifyContent: textJustification
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [titleStyle, {
      color: colors.strong
    }]
  }, title)) : null, leftDescription ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: "row",
      justifyContent: textJustification,
      alignItems: "center",
      marginTop: numColumns === 3 ? spacing.text : spacing.text / 2
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [typography.body2, {
      color: colors.medium
    }]
  }, leftDescription), rightDescription ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [typography.subtitle2, {
      color: colors.light
    }]
  }, rightDescription) : null) : null), icon ? /*#__PURE__*/_react.default.createElement(_Elevation.default, {
    style: {
      elevation: _Config.default.cardIconElevation,
      position: "absolute",
      top: spacing.medium,
      right: spacing.medium,
      width: ICON_CONTAINER_SIZE,
      height: ICON_CONTAINER_SIZE,
      padding: ICON_CONTAINER_PADDING,
      borderRadius: ICON_CONTAINER_SIZE,
      backgroundColor: (0, _color.default)(colors.strong).alpha(_Config.default.cardIconBackgroundOpacity).rgb().string()
    }
  }, /*#__PURE__*/_react.default.createElement(_Icon.default, {
    name: icon,
    size: _Config.default.cardIconSize,
    color: colors.surface
  })) : null)));
};

var _default = (0, _theming.withTheme)(CardContainer);

exports.default = _default;
const SEED_DATA_PROPS = {
  image: {
    label: "Image",
    description: "Image",
    formType: _componentTypes.FORM_TYPES.remoteImage,
    propType: _componentTypes.PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: true,
    group: _componentTypes.GROUPS.data
  },
  title: {
    label: "Title",
    description: "Text to display",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "Beautiful West Coast Villa",
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.data
  },
  leftDescription: {
    label: "Left description",
    description: "Text to display on the left",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "San Diego",
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.data
  },
  rightDescription: {
    label: "Right description",
    description: "Text to display on the right",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "$100",
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.data
  },
  icon: {
    label: "Icon",
    description: "Icon to display on the top right",
    formType: _componentTypes.FORM_TYPES.icon,
    propType: _componentTypes.PROP_TYPES.STRING
    /* OR ASSET TODO TEST ME */
    ,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  aspectRatio: {
    label: "Aspect ratio",
    description: "Aspect ratio of the image",
    formType: _componentTypes.FORM_TYPES.aspectRatio,
    propType: _componentTypes.PROP_TYPES.NUMBER,
    defaultValue: 1.5,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  textCentered: {
    label: "Centered Text",
    description: "Whether to center the text",
    formType: _componentTypes.FORM_TYPES.boolean,
    propType: _componentTypes.PROP_TYPES.BOOLEAN,
    defaultValue: false,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  elevation: (0, _componentTypes.createElevationType)(2)
};
const SEED_DATA = [{
  name: "Medium Card",
  tag: "CardContainer",
  description: "An elevated card with a title and description, that takes up half of its container.",
  category: _componentTypes.COMPONENT_TYPES.card,
  layout: null,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: (0, _componentTypes.createNumColumnsType)({
      defaultValue: 2
    })
  })
}, {
  name: "Large Card",
  tag: "CardContainer",
  description: "An elevated card with a title and description, that takes up its full container.",
  category: _componentTypes.COMPONENT_TYPES.card,
  layout: null,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: (0, _componentTypes.createNumColumnsType)({
      defaultValue: 3
    })
  })
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=CardContainer.js.map