"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _Elevation = _interopRequireDefault(require("./Elevation"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _Config = _interopRequireDefault(require("./Config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const screenWidth = _reactNative.Dimensions.get("window").width;

const Carousel = ({
  images = [_Config.default.placeholderImageURL, _Config.default.placeholderImageURL, _Config.default.placeholderImageURL, _Config.default.placeholderImageURL, _Config.default.placeholderImageURL, _Config.default.placeholderImageURL, _Config.default.placeholderImageURL],
  aspectRatio,
  swiperPalette,
  resizeMode = "cover",
  dotColor,
  theme: {
    colors,
    spacing
  },
  style = {
    height: screenWidth * 0.5
  }
}) => {
  const [scrollOffset, setScrollOffset] = (0, _react.useState)(0);
  const [width, setWidth] = (0, _react.useState)(0);

  const handleScroll = e => {
    setScrollOffset(e.nativeEvent.contentOffset.x);
  };

  const onPageLayout = () => {
    const s = style;

    if (s.width) {
      setWidth(typeof s.width === "string" ? +s.width : s.width);
    } else {
      setWidth(screenWidth);
    }
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, {
      aspectRatio,
      width
    }, style],
    onLayout: onPageLayout
  }, /*#__PURE__*/_react.default.createElement(_reactNative.ScrollView, {
    onScroll: handleScroll,
    horizontal: true,
    pagingEnabled: true,
    showsHorizontalScrollIndicator: _reactNative.Platform.OS === "web",
    scrollEventThrottle: 16
  }, images.map((image, index) => {
    const imageStyle = {
      width
    };

    if (aspectRatio) {
      imageStyle.aspectRatio = aspectRatio;
    } else {
      imageStyle.flex = 1;
    }

    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.slidingPanel, {
        width
      }],
      key: index
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
      source: typeof image === "string" ? {
        uri: image
      } : image,
      resizeMode: resizeMode,
      style: {
        width,
        flex: 1,
        aspectRatio,
        height: style.height
      }
    }));
  })), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.swipeNavWrapper, {
      bottom: spacing.large
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.swipeNav
  }, Array.from({
    length: images.length
  }, (_, i) => {
    const calculatedIndex = scrollOffset / width;
    const activeDot = calculatedIndex >= i - 0.5 && calculatedIndex < i + 0.5;
    let backgroundColor;

    if (dotColor) {
      backgroundColor = dotColor;
    } else {
      if (swiperPalette === "surface") {
        if (activeDot) {
          backgroundColor = colors.strong;
        } else {
          backgroundColor = colors.light;
        }
      } else {
        if (activeDot) {
          backgroundColor = colors.background;
        } else {
          backgroundColor = colors.surface;
        }
      }
    }

    return /*#__PURE__*/_react.default.createElement(_Elevation.default, {
      key: i,
      style: [{
        backgroundColor,
        marginHorizontal: spacing.small / 2
      }, styles.dot, activeDot ? styles.activeDot : null]
    });
  }))));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    alignSelf: "stretch"
  },
  slidingPanel: {
    alignItems: "center",
    justifyContent: "center",
    flex: 1
  },
  swipeNavWrapper: {
    position: "absolute",
    justifyContent: "center",
    alignItems: "center",
    left: 0,
    right: 0
  },
  swipeNav: {
    flex: 1,
    flexDirection: "row",
    alignItems: "center",
    justifyContent: "center"
  },
  dot: {
    opacity: 0.5,
    width: _Config.default.swiperInactiveDotSize,
    height: _Config.default.swiperInactiveDotSize,
    borderRadius: _Config.default.swiperInactiveDotSize
  },
  activeDot: {
    opacity: 1,
    elevation: 1,
    width: _Config.default.swiperActiveDotSize,
    height: _Config.default.swiperActiveDotSize,
    borderRadius: _Config.default.swiperActiveDotSize
  }
});

var _default = (0, _theming.withTheme)(Carousel);

exports.default = _default;
const SEED_DATA = [{
  name: "Carousel",
  tag: "Carousel",
  category: _componentTypes.COMPONENT_TYPES.blocks,
  description: "A horizontal scrolling carousel of images",
  preview_image_url: "{CLOUDINARY_URL}/Carousel.png",
  supports_list_render: false,
  layout: {
    height: 250
  },
  props: {
    images: {
      group: _componentTypes.GROUPS.data,
      label: "Images",
      description: "A series of images to display in the carousel",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.localImageArray,
      propType: _componentTypes.PROP_TYPES.ASSET,
      defaultValue: null
    },
    resizeMode: {
      group: _componentTypes.GROUPS.basic,
      label: "Resize Mode",
      description: "Determines how to resize the images when the frame doesn't match the raw image dimensions",
      editable: true,
      required: false,
      defaultValue: "cover",
      formType: _componentTypes.FORM_TYPES.flatArray,
      propType: _componentTypes.PROP_TYPES.STRING,
      options: ["cover", "contain", "stretch", "repeat", "center"]
    },
    dotColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Dot Color",
      description: "Color of the carousel's dots",
      editable: true,
      required: true,
      defaultValue: "strong",
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME
    }
  }
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=Carousel.js.map