"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _theming = require("../core/theming");

var _Elevation = _interopRequireDefault(require("./Elevation"));

var _componentTypes = require("../core/component-types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Container = ({
  theme: {
    spacing
  },
  useThemeGutterPadding,
  borderColor,
  borderWidth,
  backgroundColor,
  backgroundImage,
  backgroundImageResizeMode,
  elevation,
  style,
  children
}) => {
  const containerStyle = {
    paddingHorizontal: useThemeGutterPadding ? spacing.gutters : 0,
    backgroundColor,
    borderColor,
    borderWidth,
    width: "100%"
  };
  const Wrap = elevation ? _Elevation.default : _reactNative.View;

  if (elevation) {
    containerStyle.elevation = elevation;
  }

  return /*#__PURE__*/React.createElement(Wrap, {
    style: [containerStyle, style]
  }, /*#__PURE__*/React.createElement(React.Fragment, null, backgroundImage ? /*#__PURE__*/React.createElement(_reactNative.Image, {
    source: typeof backgroundImage === "string" ? {
      uri: backgroundImage
    } : backgroundImage,
    resizeMode: backgroundImageResizeMode,
    style: {
      width: "100%",
      height: "100%"
    }
  }) : null, children));
};

var _default = (0, _theming.withTheme)(Container);

exports.default = _default;
const SEED_DATA = {
  name: "Container",
  tag: "Container",
  description: "A container component with gutter padding",
  category: _componentTypes.COMPONENT_TYPES.layout,
  supports_list_render: false,
  layout: {},
  props: {
    useThemeGutterPadding: {
      group: _componentTypes.GROUPS.basic,
      label: "Use gutter padding",
      description: "When true, uses the theme gutter spacing as the container's horizontal padding",
      formType: _componentTypes.FORM_TYPES.boolean,
      defaultValue: true,
      editable: true,
      required: true
    },
    backgroundImage: {
      group: _componentTypes.GROUPS.data,
      label: "Background image",
      description: "Background image to apply to the container",
      formType: _componentTypes.FORM_TYPES.remoteImage,
      defaultValue: null,
      editable: true,
      required: false
    },
    backgroundImageResizeMode: {
      group: _componentTypes.GROUPS.basic,
      label: "Background image resize mode",
      description: "Determines how to resize the background image when the frame doesn't match the raw image dimensions",
      editable: true,
      required: false,
      defaultValue: null,
      formType: _componentTypes.FORM_TYPES.flatArray,
      options: ["cover", "contain", "stretch", "repeat", "center"]
    },
    elevation: (0, _componentTypes.createElevationType)(0)
  }
};
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=Container.js.map