"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _reactNative = require("react-native");

var _Touchable = _interopRequireDefault(require("./Touchable"));

var _Checkbox = _interopRequireDefault(require("./Checkbox"));

var _color = _interopRequireDefault(require("color"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const FieldCheckbox = ({
  title,
  status,
  onPress: _onPress,
  color: checkboxColor,
  disabled = false,
  theme: {
    colors,
    typography,
    spacing,
    disabledOpacity
  }
}) => {
  let titleColor = status === "checked" ? colors.medium : colors.light;

  if (disabled) {
    titleColor = (0, _color.default)(titleColor).alpha(disabledOpacity).rgb().string();
  }

  return /*#__PURE__*/React.createElement(_Touchable.default, {
    onPress: _onPress,
    disabled: disabled
  }, /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(_Checkbox.default, {
    status: status,
    disabled: disabled,
    color: checkboxColor,
    onPress: () => {
      if (_onPress) {
        _onPress();
      }
    }
  }), /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: [typography.body1, {
      marginLeft: spacing.medium,
      color: titleColor
    }]
  }, title)));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    flexDirection: "row",
    alignItems: "center"
  }
});

var _default = (0, _theming.withTheme)(FieldCheckbox);

exports.default = _default;
const SEED_DATA = [{
  name: "Field Checkbox",
  tag: "FieldCheckbox",
  description: "A row with left aligned checkbox and body",
  preview_image_url: "{CLOUDINARY_URL}/Field_Checkbox.png",
  category: _componentTypes.COMPONENT_TYPES.field,
  supports_list_render: true,
  props: {
    title: {
      group: _componentTypes.GROUPS.data,
      label: "Title",
      description: "Text to display",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true
    },
    color: {
      group: _componentTypes.GROUPS.basic,
      label: "Color",
      description: "Custom color for the checkbox",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: null
    },
    disabled: {
      group: _componentTypes.GROUPS.basic,
      label: "Disabled",
      description: "Whether checkbox and headline is disabled",
      editable: true,
      required: false,
      defaultValue: false,
      formType: _componentTypes.FORM_TYPES.boolean,
      propType: _componentTypes.PROP_TYPES.BOOLEAN
    },
    fieldName: _objectSpread(_objectSpread({}, _componentTypes.FIELD_NAME), {}, {
      defaultValue: "checkboxValue",
      valuePropName: "status",
      handlerPropName: "onPress"
    })
  },
  layout: {}
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=FieldCheckbox.js.map