"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _Icon = _interopRequireDefault(require("./Icon"));

var _Config = _interopRequireDefault(require("./Config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const FieldSearchBarFull = ({
  icon = "search",
  placeholder = "",
  style,
  theme: {
    colors,
    spacing,
    typography
  },
  onChange: changeOverride,
  onSubmit: submitOverride,
  value
}) => {
  const [focused, setIsFocused] = React.useState(false);

  const onBlur = () => {
    setIsFocused(false);
  };

  const onChange = text => {
    changeOverride && changeOverride(text);
  };

  const onFocus = () => {
    setIsFocused(true);
  };

  const onSubmit = e => {
    submitOverride && submitOverride(e);
  };

  const _typography$body = typography.body2,
        {
    lineHeight
  } = _typography$body,
        typeStyles = _objectWithoutProperties(_typography$body, ["lineHeight"]); // eslint-disable-line @typescript-eslint/no-unused-vars


  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: [{
      padding: spacing.large
    }, styles.container, style]
  }, /*#__PURE__*/React.createElement(_Icon.default, {
    name: icon,
    size: _Config.default.fieldSearchBarFullIconSize,
    color: focused ? colors.primary : colors.light
  }), /*#__PURE__*/React.createElement(_reactNative.View, {
    style: {
      marginLeft: spacing.medium,
      flex: 1
    }
  }, /*#__PURE__*/React.createElement(_reactNative.TextInput, {
    clearButtonMode: "while-editing",
    placeholder: placeholder,
    value: value,
    onBlur: onBlur,
    onFocus: onFocus,
    onChangeText: onChange,
    onSubmitEditing: onSubmit,
    placeholderTextColor: colors.light,
    style: [{
      color: colors.medium
    }, typeStyles]
  })));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    flexDirection: "row",
    alignItems: "center"
  }
});

var _default = (0, _theming.withTheme)(FieldSearchBarFull);

exports.default = _default;
const SEED_DATA = [{
  name: "Search Bar",
  tag: "FieldSearchBarFull",
  description: "A search bar with accompanying search icon and clear button.",
  category: _componentTypes.COMPONENT_TYPES.field,
  preview_image_url: "{CLOUDINARY_URL}/Field_SearchBar_Full.png",
  supports_list_render: false,
  props: {
    icon: {
      group: _componentTypes.GROUPS.basic,
      label: "Icon",
      description: "Left icon to display",
      formType: _componentTypes.FORM_TYPES.icon,
      propType: _componentTypes.PROP_TYPES.ASSET,
      defaultValue: null,
      editable: true,
      required: false
    },
    placeholder: {
      group: _componentTypes.GROUPS.basic,
      label: "Placeholder",
      description: "Input placeholder text",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "Search for...",
      editable: true,
      required: false
    },
    onSubmit: {
      group: _componentTypes.GROUPS.basic,
      label: "Submit action",
      description: "Action to execute on submission",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.action,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: null
    },
    fieldName: _objectSpread(_objectSpread({}, _componentTypes.FIELD_NAME), {}, {
      defaultValue: "searchBarValue"
    })
  },
  layout: {}
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=FieldSearchBarFull.js.map