"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _theming = require("../core/theming");

var _reactNative = require("react-native");

var _Icon = _interopRequireDefault(require("./Icon"));

var _Touchable = _interopRequireDefault(require("./Touchable"));

var _componentTypes = require("../core/component-types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const RadioButtonGroup = ({
  direction = "horizontal",
  options = [],
  activeColor,
  inactiveColor,
  labelStyle,
  iconSize,
  contentColor,
  unselectedContentColor,
  borderRadius,
  optionSpacing,
  borderColor,
  style,
  value,
  theme: {
    colors
  },
  onSelect = () => {}
}) => {
  const marginHorizontal = direction === "horizontal" && optionSpacing ? optionSpacing / 2 : 0;
  const marginVertical = direction === "vertical" && optionSpacing ? optionSpacing / 2 : 0;
  const containerStyle = {
    flexDirection: direction === "vertical" ? "column" : "row",
    borderRadius: optionSpacing ? 0 : borderRadius,
    overflow: "hidden"
  };

  if (direction !== "vertical") {
    containerStyle.alignItems = "center";
  }

  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: [containerStyle, style]
  }, options.map((option, index) => {
    const selected = option.label === value;
    const textColor = selected ? contentColor && colors[contentColor] : unselectedContentColor && colors[unselectedContentColor];
    return /*#__PURE__*/React.createElement(_Touchable.default, {
      key: index,
      onPress: () => onSelect(option.label),
      style: {
        flex: 1
      }
    }, /*#__PURE__*/React.createElement(_reactNative.View, {
      style: {
        flexDirection: "row",
        alignItems: "center",
        justifyContent: "center",
        backgroundColor: selected ? activeColor && colors[activeColor] : inactiveColor && colors[inactiveColor],
        height: style ? style.height ? style.height : 50 : 50,
        borderLeftWidth: borderColor && index !== 0 ? _reactNative.StyleSheet.hairlineWidth : 0,
        borderRightWidth: borderColor && index !== options.length - 1 ? _reactNative.StyleSheet.hairlineWidth : 0,
        borderColor: borderColor ? colors[borderColor] : colors.divider,
        borderRadius: optionSpacing ? borderRadius : 0,
        marginLeft: marginHorizontal,
        marginRight: marginHorizontal,
        marginTop: marginVertical,
        marginBottom: marginVertical
      }
    }, option.icon ? /*#__PURE__*/React.createElement(_Icon.default, {
      style: {
        paddingEnd: 5
      },
      name: option.icon,
      size: iconSize,
      color: textColor
    }) : null, option.label ? /*#__PURE__*/React.createElement(_reactNative.Text, {
      style: [labelStyle, {
        color: textColor
      }]
    }, option.label) : null));
  }));
};

var _default = (0, _theming.withTheme)(RadioButtonGroup);

exports.default = _default;
const SEED_DATA = {
  name: "Radio Button Group",
  tag: "RadioButtonGroup",
  category: _componentTypes.COMPONENT_TYPES.button,
  preview_image_url: "{CLOUDINARY_URL}/Control_Radio.png",
  props: {
    options: {
      group: _componentTypes.GROUPS.data,
      label: "Options",
      description: "Options for the button group.",
      formType: _componentTypes.FORM_TYPES.array,
      propType: _componentTypes.PROP_TYPES.OBJECT,
      options: [{
        icon: "",
        label: "One"
      }, {
        icon: "",
        label: "Two"
      }, {
        icon: "",
        label: "Three"
      }],
      defaultValue: [{
        icon: "",
        label: "One"
      }, {
        icon: "",
        label: "Two"
      }, {
        icon: "",
        label: "Three"
      }],
      editable: true,
      required: true
    },
    direction: {
      group: _componentTypes.GROUPS.basic,
      label: "Horizontal/Vertical",
      description: "Whether the buttons should be Horizontal or Vertical",
      formType: _componentTypes.FORM_TYPES.flatArray,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "horizontal",
      options: ["horizontal", "vertical"],
      editable: true,
      required: true
    },
    activeColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Active Color",
      description: "Color of the button when it's selected",
      defaultValue: "primary",
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      editable: true,
      required: true
    },
    inactiveColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Inactive Color",
      description: "Color of the button when it's selected not selected",
      defaultValue: "divider",
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      editable: true,
      required: true
    },
    contentColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Selected Content Color",
      description: "Color of the content(Icon and Label)",
      defaultValue: "surface",
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      editable: true,
      required: true
    },
    unselectedContentColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Unselected Content Color",
      description: "Unfinished Color of the content(Icon and Label)",
      defaultValue: "strong",
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      editable: true,
      required: true
    },
    borderColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Border Color",
      description: "Border color of the option",
      defaultValue: "light",
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      editable: true,
      required: true
    },
    labelStyle: {
      group: _componentTypes.GROUPS.basic,
      label: "Label Style",
      description: "Font and weight of the Label",
      formType: _componentTypes.FORM_TYPES.typeStyle,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: "Button",
      editable: true,
      required: true
    },
    optionSpacing: {
      group: _componentTypes.GROUPS.basic,
      label: "Option Spacing",
      description: "The spacing between each option",
      formType: _componentTypes.FORM_TYPES.number,
      propType: _componentTypes.PROP_TYPES.NUMBER,
      defaultValue: 1,
      min: 0,
      max: 20,
      step: 1,
      precision: 1,
      editable: true,
      required: false
    },
    borderRadius: {
      group: _componentTypes.GROUPS.basic,
      label: "Border Radius",
      description: "The border radius for the container or options",
      formType: _componentTypes.FORM_TYPES.number,
      propType: _componentTypes.PROP_TYPES.NUMBER,
      defaultValue: 10,
      min: 0,
      max: 100,
      step: 1,
      precision: 1,
      editable: true,
      required: false
    },
    iconSize: {
      group: _componentTypes.GROUPS.basic,
      label: "Icon Size",
      description: "The size of the icon if enabled",
      formType: _componentTypes.FORM_TYPES.number,
      propType: _componentTypes.PROP_TYPES.NUMBER,
      defaultValue: 16,
      min: 0,
      max: 24,
      step: 1,
      precision: 1,
      editable: true,
      required: false
    },
    fieldName: _objectSpread(_objectSpread({}, _componentTypes.FIELD_NAME), {}, {
      defaultValue: "radioButtonValue",
      handlerPropName: "onSelect"
    })
  },
  layout: {}
};
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=RadioButtonGroup.js.map