"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = void 0;

var _componentTypes = require("../core/component-types");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const SEED_DATA_PROPS = {
  label: {
    label: "Label",
    description: "The label to be displayed on the picker",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "Date",
    editable: true,
    required: true,
    group: _componentTypes.GROUPS.data
  },
  mode: {
    label: "Mode",
    description: "Choose between date, time and datetime",
    defaultValue: "date",
    editable: true,
    required: true,
    formType: _componentTypes.FORM_TYPES.flatArray,
    propType: _componentTypes.PROP_TYPES.STRING,
    options: ["date", "time", "datetime"],
    group: _componentTypes.GROUPS.basic
  },
  assistiveText: {
    label: "Assistive text",
    description: "Helper text to display below the picker",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  locale: {
    label: "Locale",
    description: "Locale for the datepicker. Must be a valid Locale",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  minuteInterval: {
    label: "Minute Interval",
    description: "The interval at which minutes can be selected",
    formType: _componentTypes.FORM_TYPES.flatArray,
    propType: _componentTypes.PROP_TYPES.NUMBER,
    options: [1, 2, 3, 4, 5, 6, 10, 12, 15, 20, 30],
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  timeZoneOffsetInMinutes: {
    label: "Time zone offset",
    description: "By default, the datepicker uses the device's timezone. This will allow you to offset it",
    formType: _componentTypes.FORM_TYPES.number,
    propType: _componentTypes.PROP_TYPES.NUMBER,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  initialDate: {
    label: "Initial Date",
    description: "Optionally set an initial date to make your forms easier to work with",
    formType: _componentTypes.FORM_TYPES.date,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  options: {
    label: "Options",
    description: "Array of picker options. An array of objects containing a label and value.",
    editable: true,
    required: false,
    formType: _componentTypes.FORM_TYPES.array,
    propType: _componentTypes.PROP_TYPES.OBJECT,
    defaultValue: null,
    options: [],
    group: _componentTypes.GROUPS.data
  },
  disabled: {
    label: "Disabled",
    description: "Whether the picker should be disabled. Will prevent selection and show a greyed out state.",
    formType: _componentTypes.FORM_TYPES.boolean,
    propType: _componentTypes.PROP_TYPES.BOOLEAN,
    defaultValue: false,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  error: {
    label: "Error",
    description: "Whether the picker should display the error state",
    formType: _componentTypes.FORM_TYPES.boolean,
    propType: _componentTypes.PROP_TYPES.BOOLEAN,
    defaultValue: false,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.data
  },
  leftIconName: {
    label: "Left icon name",
    description: "The icon to display on the left",
    formType: _componentTypes.FORM_TYPES.icon,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  leftIconMode: {
    label: "Left icon mode",
    description: "The mode of the icon to display on the left. 'inset' or 'outset'.",
    formType: _componentTypes.FORM_TYPES.flatArray,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "inset",
    options: ["inset", "outset"],
    editable: true,
    required: true,
    group: _componentTypes.GROUPS.basic
  },
  rightIconName: {
    label: "Right icon name",
    description: "The icon to display on the right",
    formType: _componentTypes.FORM_TYPES.icon,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: false,
    group: _componentTypes.GROUPS.basic
  },
  fieldName: _objectSpread(_objectSpread({}, _componentTypes.FIELD_NAME), {}, {
    handlerPropName: "onDateChange",
    valuePropName: "date",
    defaultValue: "date"
  })
};
const SEED_DATA = [{
  name: "Date Picker - Solid",
  tag: "DatePicker",
  description: "A date picker with a solid border",
  category: _componentTypes.COMPONENT_TYPES.field,
  layout: null,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    type: {
      label: "Type",
      description: "Type of Datepicker",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "solid",
      editable: false,
      required: false,
      group: _componentTypes.GROUPS.basic
    }
  })
}, {
  name: "Date Picker - Underline",
  tag: "DatePicker",
  description: "A date picker with an underline",
  category: _componentTypes.COMPONENT_TYPES.field,
  layout: null,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    type: {
      label: "Type",
      description: "Type of Datepicker",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "underline",
      editable: false,
      required: false,
      group: _componentTypes.GROUPS.basic
    }
  })
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=DatePicker.js.map