function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from "react";
import { View, Text } from "react-native";
import Image from "./Image";
import Card from "./Card";
import Elevation from "./Elevation";
import { withTheme } from "../core/theming";
import { GROUPS, COMPONENT_TYPES, FORM_TYPES, createElevationType, createNumColumnsType } from "../core/component-types";
import Config from "./Config";

const CardInline = ({
  image = Config.cardImageUrl,
  title,
  description,
  textCentered,
  aspectRatio = 1.5,
  elevation = 2,
  numColumns = 3,
  theme: {
    colors,
    borderRadius,
    typography,
    spacing
  },
  style,
  onPress
}) => {
  let titleStyle, descriptionStyle;

  switch (numColumns) {
    case 1:
      titleStyle = typography.headline6;
      descriptionStyle = typography.subtitle2;
      break;

    case 2:
      titleStyle = typography.headline5;
      descriptionStyle = typography.subtitle2;
      break;

    case 3:
      titleStyle = typography.headline4;
      descriptionStyle = typography.subtitle1;
      break;
  }

  return /*#__PURE__*/React.createElement(Card, {
    style: style,
    onPress: onPress,
    numColumns: numColumns
  }, /*#__PURE__*/React.createElement(Elevation, {
    style: {
      elevation,
      borderRadius: borderRadius.global
    }
  }, /*#__PURE__*/React.createElement(Image, {
    style: {
      borderRadius: borderRadius.global,
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  }), /*#__PURE__*/React.createElement(View, {
    style: {
      position: "absolute",
      alignItems: textCentered ? "center" : "flex-start",
      bottom: numColumns === 1 ? spacing.medium : spacing.large,
      left: spacing.large,
      right: spacing.large
    }
  }, title ? /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [titleStyle, {
      color: colors.strongInverse
    }]
  }, title) : null, description ? /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [descriptionStyle, {
      color: colors.lightInverse,
      marginTop: spacing.text
    }]
  }, description) : null)));
};

export default withTheme(CardInline);
const SEED_DATA_PROPS = {
  image: {
    group: GROUPS.data,
    label: "Image",
    description: "Image",
    formType: FORM_TYPES.remoteImage,
    defaultValue: null,
    editable: true
  },
  title: {
    group: GROUPS.data,
    label: "Title",
    description: "Text to display",
    formType: FORM_TYPES.string,
    defaultValue: "Beautiful West Coast Villa",
    editable: true
  },
  textCentered: {
    group: GROUPS.basic,
    label: "Text centered",
    description: "Whether to center the text",
    formType: FORM_TYPES.boolean,
    defaultValue: false,
    editable: true
  },
  elevation: createElevationType(2)
};
export const SEED_DATA = [{
  name: "Small Card (Inline)",
  tag: "CardInline",
  description: "An elevated card with image and a centered line of text overlayed, that takes up a third of its container.",
  category: COMPONENT_TYPES.card,
  preview_image_url: "{CLOUDINARY_URL}/Card_Inline_1col.png",
  supports_list_render: true,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    aspectRatio: {
      group: GROUPS.basic,
      label: "Aspect ratio",
      description: "Aspect ratio of the image",
      formType: FORM_TYPES.aspectRatio,
      defaultValue: 1,
      editable: true
    },
    numColumns: createNumColumnsType({
      defaultValue: 1
    })
  }),
  layout: {}
}, {
  name: "Medium Card (Inline)",
  tag: "CardInline",
  description: "An elevated card with image and a title and description overlayed, that takes up half of its container.",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Card_Inline_2col.png",
  supports_list_render: true,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    description: {
      group: GROUPS.data,
      label: "Left description",
      description: "Text to display on the left",
      formType: FORM_TYPES.string,
      defaultValue: "San Diego",
      editable: true
    },
    aspectRatio: {
      group: GROUPS.basic,
      label: "Aspect ratio",
      description: "Aspect ratio of the image",
      formType: FORM_TYPES.aspectRatio,
      defaultValue: 1.5,
      editable: true
    },
    numColumns: createNumColumnsType({
      defaultValue: 2
    })
  }),
  layout: {}
}, {
  name: "Large Card (Inline)",
  tag: "CardInline",
  description: "An elevated card with image and a title and description overlayed, that takes up the full width of its container.",
  category: COMPONENT_TYPES.card,
  preview_image_url: "{CLOUDINARY_URL}/Card_Inline_3col.png",
  supports_list_render: true,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    description: {
      group: GROUPS.data,
      label: "Left description",
      description: "Text to display on the left",
      formType: FORM_TYPES.string,
      defaultValue: "San Diego",
      editable: true
    },
    aspectRatio: {
      group: GROUPS.basic,
      label: "Aspect ratio",
      description: "Aspect ratio of the image",
      formType: FORM_TYPES.aspectRatio,
      defaultValue: 1.5,
      editable: true
    },
    numColumns: createNumColumnsType({
      defaultValue: 3
    })
  }),
  layout: {}
}];
//# sourceMappingURL=CardInline.js.map