function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import * as React from "react";
import { View, StyleSheet, ActivityIndicator } from "react-native";
import Touchable from "./Touchable";
import Icon from "./Icon";
import { withTheme } from "../core/theming";
import { FORM_TYPES, COMPONENT_TYPES, GROUPS, PROP_TYPES } from "../core/component-types";

const IconButton = (_ref) => {
  let {
    icon,
    color: customColor,
    size = 32,
    accessibilityLabel,
    disabled = false,
    loading = false,
    onPress,
    theme,
    style
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["icon", "color", "size", "accessibilityLabel", "disabled", "loading", "onPress", "theme", "style"]);

  const iconColor = customColor || theme.colors.primary;
  const containerStyles = [styles.container];

  if (loading || disabled) {
    containerStyles.push({
      opacity: theme.disabledOpacity
    });
  }

  if (style) {
    containerStyles.push(style);
  }

  return /*#__PURE__*/React.createElement(Touchable, _extends({
    onPress: onPress,
    disabled: disabled || loading,
    style: containerStyles,
    accessibilityLabel: accessibilityLabel,
    accessibilityTraits: disabled ? ["button", "disabled"] : "button",
    accessibilityComponentType: "button",
    accessibilityRole: "button",
    accessibilityState: {
      disabled
    },
    hitSlop: {
      top: 6,
      left: 6,
      bottom: 6,
      right: 6
    }
  }, rest), /*#__PURE__*/React.createElement(View, null, icon && !loading ? /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    size: size,
    color: iconColor
  }) : null, loading ? /*#__PURE__*/React.createElement(ActivityIndicator, {
    size: "small",
    color: iconColor
  }) : null));
};

const styles = StyleSheet.create({
  container: {
    alignItems: "center",
    justifyContent: "center"
  }
});
export default withTheme(IconButton);
export const SEED_DATA = {
  name: "Icon Button",
  tag: "IconButton",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Button_Icon.png",
  props: {
    icon: {
      group: GROUPS.basic,
      label: "Icon Name",
      description: "Name of icon",
      editable: true,
      required: false,
      formType: FORM_TYPES.icon,
      propType: PROP_TYPES.ASSET,
      defaultValue: null
    },
    size: {
      group: GROUPS.basic,
      label: "Icon Size",
      description: "Size of icon",
      editable: true,
      required: false,
      formType: FORM_TYPES.flatArray,
      propType: PROP_TYPES.NUMBER,
      defaultValue: 32,
      options: [16, 24, 32]
    },
    color: {
      group: GROUPS.basic,
      label: "Color",
      description: "Color of the icon",
      formType: FORM_TYPES.color,
      propType: PROP_TYPES.THEME,
      defaultValue: "strong",
      editable: true,
      required: true
    },
    onPress: {
      group: GROUPS.basic,
      label: "Action",
      description: "Action to execute when icon button pressed",
      editable: true,
      formType: FORM_TYPES.action,
      propType: PROP_TYPES.STRING,
      defaultValue: null
    }
  },
  layout: {
    width: 32,
    height: 32
  }
};
//# sourceMappingURL=IconButton.js.map