function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from "react";
import { View, Text } from "react-native";
import { withTheme } from "../core/theming";
import { COMPONENT_TYPES, FORM_TYPES, GROUPS, PROP_TYPES, FIELD_NAME, BORDER_RADIUS_MODE } from "../core/component-types";
import IconButton from "./IconButton";
import theme from "../styles/DefaultTheme";

const Stepper = ({
  value = 0,
  style,
  onChange,
  theme: {
    colors,
    typography,
    spacing
  },
  iconSize = 24,
  iconColor = colors.strong,
  borderRadius = theme.borderRadius.button,
  typeStyle
}) => {
  const [stateValue, setStateValue] = React.useState(value);

  const handleMinus = () => {
    if (value || value === 0) {
      onChange && onChange(value - 1);
    } else {
      setStateValue(stateValue - 1);
    }
  };

  const handlePlus = () => {
    if (value || value === 0) {
      onChange && onChange(value + 1);
    } else {
      setStateValue(stateValue + 1);
    }
  };

  return /*#__PURE__*/React.createElement(View, {
    style: [{
      flexDirection: "row"
    }, style, borderRadius ? {
      borderRadius
    } : {}]
  }, /*#__PURE__*/React.createElement(IconButton, {
    icon: "MaterialIcons/remove",
    onPress: handleMinus,
    size: iconSize,
    color: iconColor,
    disabled: value ? value === 0 : stateValue === 0
  }), /*#__PURE__*/React.createElement(Text, {
    style: [typography.body1, {
      textAlign: "center",
      alignSelf: "center",
      color: colors.medium,
      marginHorizontal: spacing.small
    }, typeStyle]
  }, value || stateValue), /*#__PURE__*/React.createElement(IconButton, {
    icon: "MaterialIcons/add",
    onPress: handlePlus,
    size: iconSize,
    color: iconColor
  }));
};

export default withTheme(Stepper);
export const SEED_DATA = [{
  name: "Stepper",
  tag: "Stepper",
  description: "A component used to control the quantity of something",
  category: COMPONENT_TYPES.field,
  preview_image_url: "{CLOUDINARY_URL}/Control_Stepper.png",
  supports_list_render: false,
  props: {
    fieldName: _objectSpread(_objectSpread({}, FIELD_NAME), {}, {
      defaultValue: "stepperValue"
    }),
    iconSize: {
      group: GROUPS.basic,
      label: "Current Icon Size",
      description: "The size of the icons",
      editable: true,
      required: false,
      min: 0,
      max: 60,
      step: 1,
      formType: FORM_TYPES.number,
      propType: PROP_TYPES.NUMBER,
      defaultValue: 24
    },
    iconColor: {
      group: GROUPS.basic,
      label: "Current Icon Color",
      description: "The color of the icons",
      editable: true,
      required: false,
      formType: FORM_TYPES.color,
      propType: PROP_TYPES.THEME,
      defaultValue: "strong"
    },
    borderRadius: _objectSpread({}, BORDER_RADIUS_MODE)
  },
  layout: {}
}];
//# sourceMappingURL=Stepper.js.map