import * as React from "react";
import { TouchableHighlightProps, StyleProp, ViewStyle } from "react-native";
import Icon from "./Icon";
import theme from "../styles/DefaultTheme";
/**
 * A floating action button represents the primary action in an application.
 *
 * <div class="screenshots">
 *   <img src="screenshots/fab-1.png" />
 *   <img src="screenshots/fab-2.png" />
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { FAB } from '@draftbit/ui';
 *
 * const MyComponent = () => (
 *   <FAB
 *     style={styles.fab}
 *     type="outline"
 *     icon="add"
 *     onPress={() => console.log('Pressed')}
 *   />
 * );
 *
 * const styles = StyleSheet.create({
 *   fab: {
 *     position: 'absolute',
 *     margin: 16,
 *     right: 0,
 *     bottom: 0,
 *   },
 * })
 *
 * export default MyComponent;
 * ```
 */
interface Props extends TouchableHighlightProps {
    disabled?: boolean;
    type?: "solid" | "extended" | "outline" | "fixed" | "standard";
    loading?: boolean;
    icon?: string;
    color?: string;
    label?: string;
    onPress: () => void;
    elevation?: number;
    theme: typeof theme;
    IconOverride: typeof Icon;
    style?: StyleProp<ViewStyle>;
}
declare const _default: (React.ComponentClass<Pick<Props, "label" | "style" | "hitSlop" | "onLayout" | "testID" | "hasTVPreferredFocus" | "tvParallaxProperties" | "accessible" | "accessibilityActions" | "accessibilityLabel" | "accessibilityRole" | "accessibilityState" | "accessibilityHint" | "accessibilityValue" | "onAccessibilityAction" | "accessibilityComponentType" | "accessibilityLiveRegion" | "importantForAccessibility" | "accessibilityElementsHidden" | "accessibilityTraits" | "accessibilityViewIsModal" | "onAccessibilityEscape" | "onAccessibilityTap" | "onMagicTap" | "accessibilityIgnoresInvertColors" | "disabled" | "type" | "color" | "icon" | "onPress" | "onLongPress" | "activeOpacity" | "delayLongPress" | "delayPressIn" | "delayPressOut" | "onBlur" | "onFocus" | "onPressIn" | "onPressOut" | "pressRetentionOffset" | "elevation" | "loading" | "onHideUnderlay" | "onShowUnderlay" | "underlayColor" | "IconOverride"> & {
    theme?: import("@draftbit/react-theme-provider").$DeepPartial<any> | undefined;
}, any> & import("@draftbit/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<Props, any> & React.FC<Props>) | (React.FunctionComponent<Props> & React.FC<Props>), {}>) | (React.FunctionComponent<Pick<Props, "label" | "style" | "hitSlop" | "onLayout" | "testID" | "hasTVPreferredFocus" | "tvParallaxProperties" | "accessible" | "accessibilityActions" | "accessibilityLabel" | "accessibilityRole" | "accessibilityState" | "accessibilityHint" | "accessibilityValue" | "onAccessibilityAction" | "accessibilityComponentType" | "accessibilityLiveRegion" | "importantForAccessibility" | "accessibilityElementsHidden" | "accessibilityTraits" | "accessibilityViewIsModal" | "onAccessibilityEscape" | "onAccessibilityTap" | "onMagicTap" | "accessibilityIgnoresInvertColors" | "disabled" | "type" | "color" | "icon" | "onPress" | "onLongPress" | "activeOpacity" | "delayLongPress" | "delayPressIn" | "delayPressOut" | "onBlur" | "onFocus" | "onPressIn" | "onPressOut" | "pressRetentionOffset" | "elevation" | "loading" | "onHideUnderlay" | "onShowUnderlay" | "underlayColor" | "IconOverride"> & {
    theme?: import("@draftbit/react-theme-provider").$DeepPartial<any> | undefined;
}> & import("@draftbit/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<Props, any> & React.FC<Props>) | (React.FunctionComponent<Props> & React.FC<Props>), {}>);
export default _default;
export declare const SEED_DATA: ({
    name: string;
    tag: string;
    category: string;
    description: string;
    preview_image_url: string;
    props: {
        type: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: string;
        };
        label: {
            group: string;
            label: string;
            description: string;
            required: boolean;
            editable: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        icon: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        color: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        onPress: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
    };
    layout: {};
} | {
    name: string;
    tag: string;
    category: string;
    preview_image_url: string;
    props: {
        type: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            propType: string;
            formType: string;
            defaultValue: string;
        };
        label: {
            group: string;
            label: string;
            description: string;
            required: boolean;
            editable: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        icon: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        color: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        onPress: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
    };
    layout: {};
    description?: undefined;
} | {
    name: string;
    tag: string;
    category: string;
    preview_image_url: string;
    props: {
        type: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: string;
        };
        icon: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        label: {
            group: string;
            label: string;
            description: string;
            required: boolean;
            editable: boolean;
            formType: string;
            propType: string;
            defaultValue: string;
        };
        color: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
        onPress: {
            group: string;
            label: string;
            description: string;
            editable: boolean;
            required: boolean;
            formType: string;
            propType: string;
            defaultValue: null;
        };
    };
    layout: {};
    description?: undefined;
})[];
